PushOutcome

Enum PushOutcome 

pub enum PushOutcome {
    Accepted(usize),
    TooLarge,
}
Outcome of a RingBuffer::push operation.

Distinguishes between a frame being accepted (possibly with evictions) and a frame being discarded because it can never fit in the buffer.

Variants



Accepted(usize)

Frame was accepted. The usize is the number of older frames that were evicted to make room (may be 0).



TooLarge

Frame was too large to ever fit in this buffer (even when empty) and was silently discarded. No data was written.